@@ -4,8 +4,8 @@ use Mojo::Base -base;
 use Imager::Font;
 use Alien::Font::Vera;
 
-our $DATE = '2023-01-31'; # DATE
-our $VERSION = '0.001'; # TRIAL
+our $DATE = '2023-02-01'; # DATE
+our $VERSION = '0.002'; # TRIAL
 
 has primaryText     => 'black';
 has secondaryText	=> '#363636';
@@ -15,9 +15,15 @@ has infoStroke      => 'black';
 has doTitle         => 1;
 has containerStroke	=> 'black';
 has containerFill	=> 'grey';
-has itemFill        => 'blue';
+has itemFill        => '2ab1aa';
 has background      => 'white';
 has font            => sub { Imager::Font->new(file => Alien::Font::Vera::path) };
 has doSwimLanes     => 1;
 
+#26ccbb green
+#43acf2 blue
+#fd9742 orange
+#d63031 red
+#a75eeb purple
+
 1;
